# This dummy/empty module exists only so that it gets indexed in the
# CPAN module list.
package Devel::Fail::MakeTest;
my
$VERSION = do { my @r = (q$Revision: 1.3 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
1;
__END__

